#
#   apache.make
#
#   Makefile rules to build GNUstep-based apache modules
#
#   Copyright (C) 2000 Free Software Foundation, Inc.
#
#   Author:  Nicola Pero <nicola@brainstorm.co.uk> 
#
#   This file is part of the GNUstep Makefile Package.
#
#   This library is free software; you can redistribute it and/or
#   modify it under the terms of the GNU General Public License
#   as published by the Free Software Foundation; either version 2
#   of the License, or (at your option) any later version.
#   
#   You should have received a copy of the GNU General Public
#   License along with this library; see the file COPYING.LIB.
#   If not, write to the Free Software Foundation,
#   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

# prevent multiple inclusions
ifeq ($(APACHE_MAKE_LOADED),)
APACHE_MAKE_LOADED=yes

# Find out where APXS is.
ifeq ($(APXS),)
  APXS = $(shell which apxs)

  ifeq ($(APXS),)
    # This will probably crash compilation 
    # but at least the problem will be clear.
    APXS = apxs
  endif

endif

#
# Include in the common makefile rules
#
include $(GNUSTEP_MAKEFILES)/rules.make

#
# Add the Apache include directories
#
ADDITIONAL_INCLUDE_DIRS += -I$(shell $(APXS) -q INCLUDEDIR) 

#
# The name of the module is in the MODULE_NAME variable.
# The Objective-C files that gets included in the module are in xxx_OBJC_FILES
# The C files are in xxx_C_FILES
#	Where xxx is the name of the module
# The `module' in your program must be called $(MODULE_NAME)_module 
# or - set the MODULE_STRUCT variable.
#
#
#

MODULE_NAME:=$(strip $(MODULE_NAME))

ifeq ($(INTERNAL_module_NAME),)
# This part is included the first time make is invoked.

internal-all:: $(MODULE_NAME:=.all.module.variables)

internal-install:: all $(MODULE_NAME:=.install.module.variables)

internal-uninstall:: $(MODULE_NAME:=.uninstall.module.variables)

internal-clean:: $(MODULE_NAME:=.clean.module.variables)

internal-distclean:: $(MODULE_NAME:=.distclean.module.variables)

$(MODULE_NAME):
	@$(MAKE) -f $(MAKEFILE_NAME) --no-print-directory --no-keep-going \
		$@.all.module.variables

else

# This part gets included the second time make is invoked.

COMPLETE_MODULE_NAME = mod_$(INTERNAL_module_NAME)
MODULE_FILE = $(COMPLETE_MODULE_NAME)$(SHARED_LIBEXT)
#
# This is used by Apache to find out the name of your module struct.
# Eg, if MODULE_STRUCT = nicola, then your source code should contain 
#
# MODULE_VAR_EXPORT nicola_module = {
#    STANDARD_MODULE_STUFF, 
#    ...
# }
#
# You may override this on the command line if you need
#
MODULE_STRUCT = $(INTERNAL_module_NAME)

#
# You need to use ADDITIONAL_TOOL_LIBS etc as if you were building 
# a simple objective-C tool.
#

ALL_MODULE_LIBS = $(ADDITIONAL_TOOL_LIBS) $(AUXILIARY_TOOL_LIBS) $(FND_LIBS) \
   $(ADDITIONAL_OBJC_LIBS) $(AUXILIARY_OBJC_LIBS) $(OBJC_LIBS) \
   $(TARGET_SYSTEM_LIBS)

ALL_MODULE_LIBS := \
    $(shell $(WHICH_LIB_SCRIPT) $(LIB_DIRS_NO_SYSTEM) $(ALL_MODULE_LIBS) \
	debug=$(debug) profile=$(profile) shared=$(shared) libext=$(LIBEXT) \
	shared_libext=$(SHARED_LIBEXT))

#
# -A will insert the {module loading code} commented into your httpd.conf
# -a will insert the {module loading code} uncommented into your httpd.conf
# This last is the default.
#
ifeq ($(activate), no)
  APXS_ACTIVATE = -A
else
  APXS_ACTIVATE = -a
endif

#
# Internal targets
#

#
# Compilation targets
#

internal-module-all:: before-all before-$(TARGET)-all $(GNUSTEP_OBJ_DIR) \
		$(GNUSTEP_OBJ_DIR)/$(MODULE_FILE) after-$(TARGET)-all after-all

APXS_CMD = $(APXS) $(APXSFLAGS) 

$(GNUSTEP_OBJ_DIR)/$(MODULE_FILE): $(C_OBJ_FILES) $(OBJC_OBJ_FILES) $(OBJ_FILES) $(SUBPROJECT_OBJ_FILES)
	$(APXS_CMD) -c $^ -o $@ $(ALL_FRAMEWORK_DIRS) $(ALL_LIB_DIRS) $(ALL_MODULE_LIBS)

before-$(TARGET)-all::

after-$(TARGET)-all::

#
# Install and uninstall targets
#
internal-module-install:: 
	$(APXS) $(APXSFLAGS) -i $(APXS_ACTIVATE) -n '$(MODULE_STRUCT)' \
	        $(GNUSTEP_OBJ_DIR)/$(MODULE_FILE)

internal-module-uninstall:: before-uninstall after-uninstall

before-uninstall after-uninstall::

#
# Cleaning targets
#
internal-module-clean::
	rm -rf $(GNUSTEP_OBJ_DIR)

internal-module-distclean::
	rm -rf shared_obj static_obj shared_debug_obj shared_profile_obj \
	  static_debug_obj static_profile_obj shared_profile_debug_obj \
	  static_profile_debug_obj

#
# Testing targets
#
internal-module-check::

endif

endif
# module.make loaded

## Local variables:
## mode: makefile
## End:
